@@ -146,14 +146,8 @@ class OpenShift:
                 "TLS verification when communicating with k8s/okd master is disabled"
             )
 
-        self.use_argo = use_argo or bool(int(os.getenv("THOTH_USE_ARGO", 0)))
-
-        self.workflow_manager = None
-        if self.use_argo:
-            _LOGGER.info("Using Argo Workflow to run jobs")
-            from .workflows import WorkflowManager
-
-            self.workflow_manager = WorkflowManager(openshift=self)
+        self._use_argo = use_argo or bool(int(os.getenv("THOTH_USE_ARGO", 0)))
+        self._workflow_manager = None
 
     @property
     def token(self) -> str:
@@ -169,6 +163,32 @@ class OpenShift:
 
         return self._token
 
+    @property
+    def use_argo(self) -> bool:
+        """Return whether Argo Workflows are currently enabled."""
+        return self._use_argo
+
+    @use_argo.setter
+    def use_argo(self, enable: bool):
+        """Set whether Argo Workflows are enabled."""
+        if enable:
+            _LOGGER.debug("Argo Workflows enabled")
+        else:
+            _LOGGER.debug("Argo Workflows disabled")
+
+        self._use_argo = enable
+
+    @property
+    def workflow_manager(self):
+        """Return WorkflowManager instance.
+
+        This property lazily initializes the WorkflowManager.
+        """
+        if self._workflow_manager is None:
+            from .workflows import WorkflowManager
+            self._workflow_manager = WorkflowManager(openshift=self)
+        return self._workflow_manager
+
     @staticmethod
     def _set_env_var(template: Dict[str, Any], **env_var: str) -> None:
         """Set environment in the given template."""
@@ -654,6 +674,8 @@ class OpenShift:
         parameters: Dict[str, Any],
     ) -> str:
         """Schedule an inspection run."""
+        if not self.use_argo:
+            _LOGGER.warning("No legacy implementation that would use workload operator, using Argo workflows..")
         if not self.amun_inspection_namespace:
             raise ConfigurationError(
                 "Unable to schedule inspection without Amun inspection namespace being set."
@@ -1437,6 +1459,7 @@ class OpenShift:
         library_usage: Optional[Dict[Any, Any]] = None,
         origin: Optional[str] = None,
         is_s2i: Optional[bool] = None,
+        dev: bool = False,
         debug: bool = False,
         job_id: Optional[str] = None,
         limit_latest_versions: Optional[int] = None,
@@ -1474,12 +1497,15 @@ class OpenShift:
             ]
 
         template_parameters["THOTH_ADVISER_JOB_ID"] = adviser_id
+        template_parameters["THOTH_ADVISER_DEV"] = "1" if dev else "0"
         template_parameters["THOTH_ADVISER_REQUIREMENTS"] = application_stack[
             "requirements"
         ]
         template_parameters["THOTH_ADVISER_LIBRARY_USAGE"] = json.dumps(library_usage)
         template_parameters["THOTH_LOG_ADVISER"] = "DEBUG" if debug else "INFO"
-        template_parameters["THOTH_ADVISER_REQUIREMENTS_FORMAT"] = "pipenv"
+        template_parameters["THOTH_ADVISER_REQUIREMENTS_FORMAT"] = application_stack.get(
+                "requirements_format", "pipenv"
+            )
         template_parameters["THOTH_ADVISER_RECOMMENDATION_TYPE"] = recommendation_type
         template_parameters["THOTH_ADVISER_RUNTIME_ENVIRONMENT"] = json.dumps(
             runtime_environment
@@ -1541,6 +1567,7 @@ class OpenShift:
         library_usage: Optional[Dict[Any, Any]] = None,
         origin: Optional[str] = None,
         is_s2i: Optional[bool] = None,
+        dev: bool = False,
         debug: bool = False,
         job_id: Optional[str] = None,
         limit_latest_versions: Optional[int] = None,
@@ -1568,7 +1595,7 @@ class OpenShift:
                 "requirements_lock", ""
             ).replace("\n", "\\n"),
             "THOTH_ADVISER_REQUIREMENTS_FORMAT": application_stack.get(
-                "requirements_formant", "pipenv"
+                "requirements_format", "pipenv"
             ),
             "THOTH_ADVISER_RECOMMENDATION_TYPE": recommendation_type.lower(),
             "THOTH_ADVISER_RUNTIME_ENVIRONMENT": None if runtime_environment is None else json.dumps(
@@ -1587,6 +1614,7 @@ class OpenShift:
                 }
             ),
             "THOTH_ADVISER_OUTPUT": output,
+            "THOTH_ADVISER_DEV": "1" if dev else "0",
             "THOTH_LOG_ADVISER": "DEBUG" if debug else "INFO",
             "THOTH_ADVISER_JOB_ID": job_id,
             "THOTH_DOCUMENT_ID": job_id,
